@@ -9,9 +9,22 @@ Net::ISC::DHCPd::Config::SharedNetwork - Shared-network config parameter
 See L<Net::ISC::DHCPd::Config::Role> for methods and attributes without
 documentation.
 
+An instance from this class, comes from / will produce one of the
+blocks below, dependent on L</name> is set or not.
+    
+    shared-network $name_attribute_value {
+        $keyvalues_attribute_value
+        $subnets_attribute_value
+    }
+
+    shared-network {
+        $keyvalues_attribute_value
+        $subnets_attribute_value
+    }
+
 =head1 SYNOPSIS
 
-See L<Net::ISC::DHCPd::Config> for synopsis.
+See L<Net::ISC::DHCPd::Config/SYNOPSIS>.
 
 =cut
 
@@ -34,9 +47,20 @@ A list of parsed L<Net::ISC::DHCPd::Config::Subnet> objects.
 
 A list of parsed L<Net::ISC::DHCPd::Config::KeyValue> objects.
 
+=head2 name
+
+Holds a string representing the name of this shared network.
+Will be omitted if it contains an empty string.
+
 =cut
 
-sub _build_regex { qr{^\s* shared-network}x }
+has name => (
+    is => 'ro',
+    isa => 'Str',
+    default => '',
+);
+
+sub _build_regex { qr{^\s* shared-network \W* (\w*)}x }
 
 =head1 METHODS
 
@@ -47,9 +71,11 @@ See L<Net::ISC::DHCPd::Config::Role/generate>.
 =cut
 
 sub generate {
+    my $self = shift;
+
     return(
-        'shared-network {',
-        shift->generate_config_from_children,
+        'shared-network ' .($self->name ? $self->name . ' ' : '') . '{',
+        $self->generate_config_from_children,
         '}',
     );
 }
